#!/usr/bin/env python

import sys
import time
from smbus2 import SMBus, i2c_msg
import RPi.GPIO as GPIO

# Define i2c address - change if required
I2CADDR = 0x68

#define i2c bus number - change if required
I2CBUS = 22


def main(argv):
    # Define MCP3424 registers
    MCP3424_GAIN_1 = 0x00
    MCP3424_GAIN_2 = 0x01
    MCP3424_GAIN_4 = 0x02
    MCP3424_GAIN_8 = 0x03

    MCP3424_RATE_MASK = 0xC
    MCP3424_RATE_240SPS_12B = 0x0
    MCP3424_RATE_60SPS_14B = 0x4
    MCP3424_RATE_15SPS_16B = 0x8
    MCP3424_RATE_4SPS_18B = 0xC

    MCP3424_ONESHOT = 0x00
    MCP3424_CONTINOUS = 0x10

    MCP3424_CHAN_1 = 0x00
    MCP3424_CHAN_2 = 0x20
    MCP3424_CHAN_3 = 0x40
    MCP3424_CHAN_4 = 0x60

    MCP3424_RDY = 0x80

    # Create I2C bus as i2c-x
    i2cbus = SMBus(I2CBUS)

    # Init MCP3424 on PI-AIO - reset config
    i2cbus.write_byte(I2CADDR, 0)

    #command
    if (len(argv) == 2):
        if ((argv[1] == "1") | (argv[1] == "2") | (argv[1] == "3") | (argv[1] == "4")):
            channel = (int(argv[1])-1) << 5
            #print(hex(channel))
            #start conversion
            i2cbus.write_byte(I2CADDR, channel | MCP3424_RATE_15SPS_16B | MCP3424_GAIN_1 | MCP3424_RDY)
            time.sleep(0.1)
            #read data
            read = i2c_msg.read(I2CADDR, 3)
            i2cbus.i2c_rdwr(read)
            val1 = int.from_bytes(read.buf[0])
            val2 = int.from_bytes(read.buf[1])
            val = (val1 << 8) + val2
            print(val)
            status = int.from_bytes(read.buf[2])
            if ((status & MCP3424_RDY) == 0):
                vdiv = 4700.0/(4700.0+20000.0)
                max = (1<<15)-1
                v = float(val) * 2.048 / max / vdiv
                print(v)
        elif (argv[1] == "--help"):
            print("Usage: ain [n] where [n] is input number 1-4")
        else:
            print("Invalid argument: "+argv[1])
    else:
        print("Invalid arguments")

if __name__ == "__main__":
    main(sys.argv)

