#!/usr/bin/env python

import sys
import time
from smbus2 import SMBus, i2c_msg

# Define i2c address - change if required
I2CADDR = 0x60

# Define i2c bus number - change if required
I2CBUS = 22

# Define vref
VREF = 3.3

def main(argv):
    # Define MCP47CXBXX registers
    MCP47_ADDRESS_0 = 0x60
    MCP47_ADDRESS_1 = 0x61
    MCP47_ADDRESS_2 = 0x62
    MCP47_ADDRESS_3 = 0x63

    #read/write
    MCP47_WR = 0x00
    MCP47_RD = 0x06

    #commands - shifted by two bits
    MCP47_DAC0 = 0x00 << 3
    MCP47_DAC1 = 0x01 << 3
    MCP47_VREF = 0x08 << 3
    MCP47_PD = 0x09 << 3
    MCP47_GAINSTAT = 0x0a << 3

    #registers - all are 16 bits
    MCP47_VREF_VREFBUF = 0x0003
    MCP47_VREF_VREFUNBUF = 0x0002
    MCP47_VREF_INT = 0x0001
    MCP47_VREF_VDD = 0x0000

    MCP47_GAINSTAT_G1 = 0x0200
    MCP47_GAINSTAT_G0 = 0x0100
    MCP47_GAINSTAT_POR = 0x0080
    MCP47_GAINSTAT_MTPMA = 0x0040

    # Create I2C bus as i2c-x
    i2cbus = SMBus(I2CBUS)

    # Init MCP47 on PI-AIO - reset config
    write = i2c_msg.write(I2CADDR, [MCP47_GAINSTAT | MCP47_WR, 0, 0])
    i2cbus.i2c_rdwr(write)
    write = i2c_msg.write(I2CADDR, [MCP47_VREF | MCP47_WR, 0, MCP47_VREF_VDD])
    i2cbus.i2c_rdwr(write)

    #command
    if (len(argv) == 2):
        if (argv[1] == "--help"):
            print("Usage: aout [n] [v] where [n] is output number 1-2 and [v] is value")
        else:
            print("Invalid argument: "+argv[1])
    if (len(argv) == 3):
        if ((argv[1] == "1") | (argv[1] == "2")):
            channel = (int(argv[1]) - 1) << 3
            max = (1<<12)-1
            val = int(float(argv[2]) * max / VREF / 2 + 0.5)
            val1 = (val >> 8) & 0xff
            val2 = val & 0xff
            print(channel)
            print(val)
            write = i2c_msg.write(I2CADDR, [channel, val1, val2])
            i2cbus.i2c_rdwr(write)
    else:
        print("Invalid arguments")

if __name__ == "__main__":
    main(sys.argv)

