#!/usr/bin/env python

import sys
import time
from smbus import SMBus
import RPi.GPIO as GPIO

# Define i2c address - change if required
I2CADDR = 0x20

#define i2c bus number - change if required
I2CBUS = 22


def main(argv):
    # Define MCP23008 registers
    MCP_IODIR = 0x00    # IO direction 1=input 0=output
    MCP_IPOL = 0x01     # Input polarity
    MCP_GPINTEN = 0x02  # Interrupt-onchange
    MCP_DEFVAL = 0x03   # Default value for port
    MCP_INTCON = 0x04   # Interrupt control register for port
    MCP_IOCON = 0x05    # Configuration register
    MCP_GPPU = 0x06     # Pull-up resistors for port
    MCP_INTF = 0x07     # Interrupt condition for port
    MCP_INTCAP = 0x08   # Interrupt capture for port
    MCP_GPIO = 0x09     # Data port
    MCP_OLAT = 0x0a     # Output latches

    #define POI-DIN
    DIN1 = 0x1      #DIN 1 INPUT
    DIN2 = 0x2      #DIN 2 INPUT
    DIN3 = 0x4      #DIN 3 INPUT
    DIN4 = 0x8      #DIN 4 INPUT
    DOUT1 = 0x10    #DOUT 1 OUTPUT
    CLR1 = 0xef     #DOUT 1 CLEAR
    DOF1 = 0x20     #DOUT 1 FAULT INPUT
    DOUT2 = 0x40    #DOUT 2 OUTPUT
    CLR2 = 0xbf     #DOUT 2 CLEAR
    DOF2 = 0x80     #DOUT 2 FAULT INPUT

    # Unreset PI-DIO
    GPIO.setwarnings(False)
    GPIO.setmode(GPIO.BCM)
    GPIO.setup(4, GPIO.OUT)
    GPIO.output(4, GPIO.HIGH)

    # Create I2C bus as i2c-22
    i2cbus = SMBus(I2CBUS)

    # Init MCP23008 on PI-DIO
    i2cbus.write_byte_data(I2CADDR, MCP_IOCON, 0x04)  # Update configuration register
    i2cbus.write_byte_data(I2CADDR, MCP_IODIR, DIN1 | DIN2 | DIN3 | DIN4 | DOF1 | DOF2)  # Set direction

    # Read the port
    val = i2cbus.read_byte_data(I2CADDR, MCP_GPIO)  # Read the value of Port B

    #command
    if (len(argv) == 1):
        print(val) # print the value of port
    elif (len(argv) == 2):
        if (argv[1] == "din1"):
            print(1 if (val & DIN1) else 0)
        elif (argv[1] == "din2"):
            print(1 if (val & DIN2) else 0)
        elif (argv[1] == "din3"):
            print(1 if (val & DIN3) else 0)
        elif (argv[1] == "din4"):
            print(1 if (val & DIN4) else 0)
        elif (argv[1] == "dout1"):
            print(1 if (val & DOUT1) else 0)
        elif (argv[1] == "dof1"):
            print(1 if (val & DOF1) else 0)
        elif (argv[1] == "dout2"):
            print(1 if (val & DOUT2) else 0)
        elif (argv[1] == "dof2"):
            print(1 if (val & DOF2) else 0)
        elif (argv[1] == "--help"):
            print("Usage:")
            print("  din1       Read input 1")
            print("  din2       Read input 2")
            print("  din3       Read input 3")
            print("  din4       Read input 4")
            print("  dout1      Get output 1 state")
            print("  dout1 0|1  Set output 1 state")
            print("  dof1       Get output 1 fault state")
            print("  dout2      Get output 2 state")
            print("  dout2 0|1  Set output 2 state")
            print("  dof2       Get output 2 fault state")
        else:
            print("Invalid argument: "+argv[1])
    elif (len(argv) == 3):
        if (argv[1] == "dout1"):
            if (argv[2] == "1"):
                val = val | DOUT1
                i2cbus.write_byte_data(I2CADDR, MCP_GPIO, val)
            elif (argv[2] == "0"):
                val = val & CLR1
                i2cbus.write_byte_data(I2CADDR, MCP_GPIO, val)
            else:
                print("Invalid value: "+argv[2])
        elif (argv[1] == "dout2"):
            if (argv[2] == "1"):
                val = val | DOUT2
                i2cbus.write_byte_data(I2CADDR, MCP_GPIO, val)
            elif (argv[2] == "0"):
                val = val & CLR2
                i2cbus.write_byte_data(I2CADDR, MCP_GPIO, val)
            else:
                print("Invalid value: "+argv[2])
        else:
            print("Invalid argument: "+argv[1])
    else:
        print("Invalid arguments")

if __name__ == "__main__":
    main(sys.argv)

